==> taxipilot-0.9.1.tar.gz: taxipilot-0.9.1/taxipilot/defines.h <==
/***************************************************************************
                          defines.h  -  description
                             -------------------
    begin                : Sun Sep 30 2001, 2004
    copyright            : (C) 2001 by Thomas Friedrichsmeier
    email                : Thomas.Friedrichsmeier@ruhr-uni-bochum.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef DEFINES_H
#define DEFINES_H

// Defines: these might not all be in place yet, so some might not change anything!


// speed
#define TEXT_SPEED			300
#define CREDITS_SPEED			100
#define ACCELERATION			0.1

// timer-periods
#define PASSENGER_TP  		5000
#define OBJECTS_AP			30
#define PASSENGER_AP		50

#define TAXI_FLAPS_TP			50

// position
#define LEVEL_Z 				50
#define TAXI_Z				75
#define TAXI_FLYING_Z			70
#define TAXI_FLAPS_Z			80
#define FADER_Z				100
#define MESSAGE_Z			110
#define PASSENGER_Z		40

// other
#define FUEL_UP_EMPTY_BY 	100

// size and font
#define LABEL_FONT			"helvetica"
#define LABEL_FONT_SIZE		16
#define CREDITS_FONT			"helvetica"
#define CREDITS_FONT_SIZE	16
#define CREDITS_FONT_COLOR	yellow
#define MESSAGE_FONT      		"helvetica"
	// this is maximum font size. Actual size might be lower to fit message on screen. see display_message ()
#define MESSAGE_FONT_SIZE 	24
#define SPACE_TEXT_FONT		"helvetica"
#define SPACE_TEXT_FONT_SIZE	14
#define SPACE_TEXT_COLOR	yellow
#define MESSAGE_COLOR		white

// message-defines and crash "how"-defines (in calls to crash (int how))
// don't mess with these, they're internal

#define GAME_OVER	 		1
#define NEXT_LEVEL			2
#define EXTRA_LIFE			4
#define CRASH				8
#define CRASH_BACKGR		16
#define CRASH_PASSENGER		32
#define MISSION_COMPLETE 	64
#define LOW_FUEL			128
#define PAUSE				256
#define NEW_GAME			512

// no compatibility, please
#define KDE_NO_COMPAT

#include <kdeversion.h>
// the lowest version we test for is KDE 3.1.0. This version is the first to come with KDE_IS_VERSION.
// Hence we can safely:
#ifndef KDE_IS_VERSION
#define KDE_IS_VERSION(a,b,c) ( false )
#endif

#endif

==> taxipilot-0.9.2.tar.gz: taxipilot-0.9.2/taxipilot/defines.h <==
/***************************************************************************
                          defines.h  -  description
                             -------------------
    begin                : Sun Sep 30 2001, 2004
    copyright            : (C) 2001 by Thomas Friedrichsmeier
    email                : Thomas.Friedrichsmeier@ruhr-uni-bochum.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef DEFINES_H
#define DEFINES_H

// Defines: these might not all be in place yet, so some might not change anything!


// speed
#define TEXT_SPEED			300
#define CREDITS_SPEED			100
#define ACCELERATION			0.1

// timer-periods
#define PASSENGER_TP  		5000
#define OBJECTS_AP			30
#define PASSENGER_AP		50

#define TAXI_FLAPS_TP			50

// position
#define LEVEL_Z 				50
#define TAXI_Z				75
#define TAXI_FLYING_Z			70
#define TAXI_FLAPS_Z			80
#define FADER_Z				100
#define MESSAGE_Z			110
#define PASSENGER_Z		40

// other
#define FUEL_UP_EMPTY_BY 	100

// size and font
#define LABEL_FONT			"helvetica"
#define LABEL_FONT_SIZE		16
#define CREDITS_FONT			"helvetica"
#define CREDITS_FONT_SIZE	16
#define CREDITS_FONT_COLOR	yellow
#define MESSAGE_FONT      		"arial"
	// this is maximum font size. Actual size might be lower to fit message on screen. see display_message ()
#define MESSAGE_FONT_SIZE 	24
#define SPACE_TEXT_FONT		"arial"
#define SPACE_TEXT_FONT_SIZE	14
#define SPACE_TEXT_COLOR	yellow
#define MESSAGE_COLOR		white

// message-defines and crash "how"-defines (in calls to crash (int how))
// don't mess with these, they're internal

#define GAME_OVER			1
#define NEXT_LEVEL			2
#define EXTRA_LIFE			4
#define CRASH				8
#define CRASH_BACKGR		16
#define CRASH_PASSENGER		32
#define MISSION_COMPLETE 	64
#define LOW_FUEL			128
#define PAUSE				256
#define NEW_GAME			512

// no compatibility, please
#define KDE_NO_COMPAT

#include <kdeversion.h>
// the lowest version we test for is KDE 3.1.0. This version is the first to come with KDE_IS_VERSION.
// Hence we can safely:
#ifndef KDE_IS_VERSION
#define KDE_IS_VERSION(a,b,c) ( false )
#endif

#endif
